@@ -30,6 +30,7 @@ import (
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/container/windows"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/docker"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/featureflags"
+	"gitlab.com/gitlab-org/gitlab-runner/helpers/test"
 )
 
 var getWindowsImageOnce sync.Once
@@ -68,9 +69,8 @@ func (s *safeBuffer) String() string {
 }
 
 func TestDockerCommandSuccessRun(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
+	test.SkipIfGitLabCIOn(t, test.OSWindows)
 
 	build := getBuildForOS(t, common.GetRemoteSuccessfulBuild)
 
@@ -80,6 +80,7 @@ func TestDockerCommandSuccessRun(t *testing.T) {
 
 func TestDockerCommandMultistepBuild(t *testing.T) {
 	helpers.SkipIntegrationTests(t, "docker", "info")
+	test.SkipIfGitLabCIOn(t, test.OSWindows)
 
 	tests := map[string]struct {
 		buildGetter    func() (common.JobResponse, error)
@@ -195,9 +196,8 @@ func getWindowsImage(t *testing.T) string {
 }
 
 func TestDockerCommandSuccessRunRawVariable(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
+	test.SkipIfGitLabCIOn(t, test.OSWindows)
 
 	build := getBuildForOS(t, func() (common.JobResponse, error) {
 		return common.GetRemoteBuildResponse("echo $TEST")
@@ -216,9 +216,8 @@ func TestDockerCommandSuccessRunRawVariable(t *testing.T) {
 }
 
 func TestDockerCommandUsingCustomClonePath(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
+	test.SkipIfGitLabCIOn(t, test.OSWindows)
 
 	remoteBuild := func() (common.JobResponse, error) {
 		cmd := "ls -al $CI_BUILDS_DIR/go/src/gitlab.com/gitlab-org/repo"
@@ -263,9 +262,8 @@ func TestDockerCommandUsingCustomClonePath(t *testing.T) {
 }
 
 func TestDockerCommandNoRootImage(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
+	test.SkipIfGitLabCIOn(t, test.OSWindows)
 
 	successfulBuild, err := common.GetRemoteSuccessfulBuildWithDumpedVariables()
 
@@ -288,22 +286,20 @@ func TestDockerCommandNoRootImage(t *testing.T) {
 }
 
 func TestDockerCommandBuildFail(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
+	test.SkipIfGitLabCIOn(t, test.OSWindows)
 
 	build := getBuildForOS(t, common.GetRemoteFailedBuild)
 
 	err := build.Run(&common.Config{}, &common.Trace{Writer: os.Stdout})
 	require.Error(t, err, "error")
-	assert.IsType(t, err, &common.BuildError{})
+	assert.IsType(t, &common.BuildError{}, err)
 	assert.Contains(t, err.Error(), "exit code 1")
 }
 
 func TestDockerCommandWithAllowedImagesRun(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
+	test.SkipIfGitLabCIOn(t, test.OSWindows)
 
 	successfulBuild, err := common.GetRemoteSuccessfulBuild()
 	successfulBuild.Image = common.Image{Name: "$IMAGE_NAME"}
@@ -336,9 +332,8 @@ func TestDockerCommandWithAllowedImagesRun(t *testing.T) {
 }
 
 func TestDockerCommandDisableEntrypointOverwrite(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
+	test.SkipIfGitLabCIOn(t, test.OSWindows)
 
 	tests := []struct {
 		name     string
@@ -463,9 +458,8 @@ func TestDockerCommandMissingTag(t *testing.T) {
 }
 
 func TestDockerCommandBuildAbort(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
+	test.SkipIfGitLabCIOn(t, test.OSWindows)
 
 	longRunningBuild, err := common.GetRemoteLongRunningBuild()
 	assert.NoError(t, err)
@@ -510,7 +504,7 @@ func TestDockerCommandBuildCancel(t *testing.T) {
 
 	abortTimer := time.AfterFunc(time.Second, func() {
 		t.Log("Interrupt")
-		trace.CancelFunc()
+		trace.Cancel()
 	})
 	defer abortTimer.Stop()
 
@@ -521,14 +515,13 @@ func TestDockerCommandBuildCancel(t *testing.T) {
 	defer timeoutTimer.Stop()
 
 	err := build.Run(&common.Config{}, trace)
-	assert.IsType(t, err, &common.BuildError{})
+	assert.IsType(t, &common.BuildError{}, err)
 	assert.Contains(t, err.Error(), "canceled")
 }
 
 func TestDockerCommandTwoServicesFromOneImage(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
+	test.SkipIfGitLabCIOn(t, test.OSWindows)
 
 	tests := map[string]struct {
 		variables common.JobVariables
@@ -582,9 +575,8 @@ func TestDockerCommandTwoServicesFromOneImage(t *testing.T) {
 }
 
 func TestDockerCommandOutput(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
+	test.SkipIfGitLabCIOn(t, test.OSWindows)
 
 	successfulBuild, err := common.GetRemoteSuccessfulBuild()
 	assert.NoError(t, err)
@@ -613,6 +605,7 @@ func TestDockerCommandOutput(t *testing.T) {
 }
 
 func TestDockerPrivilegedServiceAccessingBuildsFolder(t *testing.T) {
+	test.SkipIfGitLabCIOn(t, test.OSWindows)
 	if helpers.SkipIntegrationTests(t, "docker", "info") {
 		return
 	}
@@ -702,6 +695,7 @@ func getTestDockerJob(t *testing.T) *common.Build {
 }
 
 func TestDockerExtendedConfigurationFromJob(t *testing.T) {
+	test.SkipIfGitLabCIOn(t, test.OSWindows)
 	if helpers.SkipIntegrationTests(t, "docker", "info") {
 		return
 	}
@@ -771,6 +765,7 @@ func runTestJobWithOutput(t *testing.T, build *common.Build) (output string) {
 }
 
 func TestCacheInContainer(t *testing.T) {
+	test.SkipIfGitLabCIOn(t, test.OSWindows)
 	if helpers.SkipIntegrationTests(t, "docker", "info") {
 		return
 	}
@@ -814,15 +809,39 @@ func TestCacheInContainer(t *testing.T) {
 	// The first job lacks any cache to pull, but tries to both pull and push
 	output := runTestJobWithOutput(t, build)
 	assert.Regexp(t, cacheNotPresentRE, output, "First job execution should not have cached data")
-	assert.NotContains(t, output, skipCacheDownload, "Cache download should be performed with policy: %s", common.CachePolicyPullPush)
-	assert.NotContains(t, output, skipCacheUpload, "Cache upload should be performed with policy: %s", common.CachePolicyPullPush)
+	assert.NotContains(
+		t,
+		output,
+		skipCacheDownload,
+		"Cache download should be performed with policy: %s",
+		common.CachePolicyPullPush,
+	)
+	assert.NotContains(
+		t,
+		output,
+		skipCacheUpload,
+		"Cache upload should be performed with policy: %s",
+		common.CachePolicyPullPush,
+	)
 
 	// pull-only jobs should skip the push step
 	build.JobResponse.Cache[0].Policy = common.CachePolicyPull
 	output = runTestJobWithOutput(t, build)
 	assert.NotRegexp(t, cacheNotPresentRE, output, "Second job execution should have cached data")
-	assert.NotContains(t, output, skipCacheDownload, "Cache download should be performed with policy: %s", common.CachePolicyPull)
-	assert.Contains(t, output, skipCacheUpload, "Cache upload should be skipped with policy: %s", common.CachePolicyPull)
+	assert.NotContains(
+		t,
+		output,
+		skipCacheDownload,
+		"Cache download should be performed with policy: %s",
+		common.CachePolicyPull,
+	)
+	assert.Contains(
+		t,
+		output,
+		skipCacheUpload,
+		"Cache upload should be skipped with policy: %s",
+		common.CachePolicyPull,
+	)
 
 	// push-only jobs should skip the pull step
 	build.JobResponse.Cache[0].Policy = common.CachePolicyPush
@@ -833,6 +852,7 @@ func TestCacheInContainer(t *testing.T) {
 }
 
 func TestDockerImageNameFromVariable(t *testing.T) {
+	test.SkipIfGitLabCIOn(t, test.OSWindows)
 	if helpers.SkipIntegrationTests(t, "docker", "info") {
 		return
 	}
@@ -867,6 +887,7 @@ func TestDockerImageNameFromVariable(t *testing.T) {
 }
 
 func TestDockerServiceNameFromVariable(t *testing.T) {
+	test.SkipIfGitLabCIOn(t, test.OSWindows)
 	if helpers.SkipIntegrationTests(t, "docker", "info") {
 		return
 	}
@@ -955,7 +976,7 @@ func testDockerVersion(t *testing.T, version string) {
 	}
 
 	defer func() {
-		exec.Command("docker", "rm", "-f", "-v", id).Run()
+		_ = exec.Command("docker", "rm", "-f", "-v", id).Run()
 	}()
 
 	t.Log("Getting address of", version, "...")
@@ -996,81 +1017,50 @@ func testDockerVersion(t *testing.T, version string) {
 }
 
 func TestDocker1_8Compatibility(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
-	if os.Getenv("CI") != "" {
-		t.Skip("This test doesn't work in nested dind")
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
+	test.SkipIfGitLabCIWithMessage(t, "This test doesn't work in nested dind")
 
 	testDockerVersion(t, "1.8")
 }
 
 func TestDocker1_9Compatibility(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
-	if os.Getenv("CI") != "" {
-		t.Skip("This test doesn't work in nested dind")
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
+	test.SkipIfGitLabCIWithMessage(t, "This test doesn't work in nested dind")
 
 	testDockerVersion(t, "1.9")
 }
 
 func TestDocker1_10Compatibility(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
-	if os.Getenv("CI") != "" {
-		t.Skip("This test doesn't work in nested dind")
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
+	test.SkipIfGitLabCIWithMessage(t, "This test doesn't work in nested dind")
 
 	testDockerVersion(t, "1.10")
 }
 
 func TestDocker1_11Compatibility(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
-	if os.Getenv("CI") != "" {
-		t.Skip("This test doesn't work in nested dind")
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
+	test.SkipIfGitLabCIWithMessage(t, "This test doesn't work in nested dind")
 
 	testDockerVersion(t, "1.11")
 }
 
 func TestDocker1_12Compatibility(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
-	if os.Getenv("CI") != "" {
-		t.Skip("This test doesn't work in nested dind")
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
+	test.SkipIfGitLabCIWithMessage(t, "This test doesn't work in nested dind")
 
 	testDockerVersion(t, "1.12")
 }
 
 func TestDocker1_13Compatibility(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
-	if os.Getenv("CI") != "" {
-		t.Skip("This test doesn't work in nested dind")
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
+	test.SkipIfGitLabCIWithMessage(t, "This test doesn't work in nested dind")
 
 	testDockerVersion(t, "1.13")
 }
 
 func TestDockerCommandWithBrokenGitSSLCAInfo(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
+	test.SkipIfGitLabCIOn(t, test.OSWindows)
 
 	successfulBuild, err := common.GetRemoteBrokenTLSBuild()
 	assert.NoError(t, err)
@@ -1100,9 +1090,8 @@ func TestDockerCommandWithBrokenGitSSLCAInfo(t *testing.T) {
 }
 
 func TestDockerCommandWithGitSSLCAInfo(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
+	test.SkipIfGitLabCIOn(t, test.OSWindows)
 
 	successfulBuild, err := common.GetRemoteGitLabComTLSBuild()
 	assert.NoError(t, err)
@@ -1132,9 +1121,8 @@ func TestDockerCommandWithGitSSLCAInfo(t *testing.T) {
 }
 
 func TestDockerCommandWithHelperImageConfig(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
+	test.SkipIfGitLabCIOn(t, test.OSWindows)
 
 	helperImageConfig := "gitlab/gitlab-runner-helper:x86_64-5a147c92"
 
@@ -1158,13 +1146,16 @@ func TestDockerCommandWithHelperImageConfig(t *testing.T) {
 	err = build.Run(&common.Config{}, &common.Trace{Writer: &buffer})
 	assert.NoError(t, err)
 	out := buffer.String()
-	assert.Contains(t, out, "Using docker image sha256:3cf24b1b62b6a4c55c5de43db4f50c0ff8b455238c836945d4b5c645411bfc77 for gitlab/gitlab-runner-helper:x86_64-5a147c92 ...")
+	assert.Contains(
+		t,
+		out,
+		"Using docker image sha256:3cf24b1b62b6a4c55c5de43db4f50c0ff8b455238c836945d4b5c645411bfc77 for "+
+			"gitlab/gitlab-runner-helper:x86_64-5a147c92 ...")
 }
 
 func TestDockerCommandWithDoingPruneAndAfterScript(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
+	test.SkipIfGitLabCIOn(t, test.OSWindows)
 
 	successfulBuild, err := common.GetRemoteSuccessfulBuildWithAfterScript()
 
@@ -1257,7 +1248,13 @@ func TestDockerCommandRunAttempts(t *testing.T) {
 		assertFailedToInspectContainer(t, trace, &attempts)
 	}
 
-	assert.Equal(t, executorStageAttempts, attempts, "The %s stage should be retried at least once", "step_script")
+	assert.Equal(
+		t,
+		executorStageAttempts,
+		attempts,
+		"The %s stage should be retried at least once",
+		"step_script",
+	)
 	<-runFinished
 }
 
@@ -1362,7 +1359,7 @@ func TestDockerCommand_WriteToVolumeNonRootImage(t *testing.T) {
 	defer func() {
 		volumeName := fmt.Sprintf("%s-cache-%x", build.ProjectUniqueName(), md5.Sum([]byte(volumeBind)))
 
-		err := client.VolumeRemove(context.Background(), volumeName, true)
+		err = client.VolumeRemove(context.Background(), volumeName, true)
 		require.NoError(t, err)
 	}()
 
