@@ -32,28 +32,34 @@ var flags = []FeatureFlag{
 		DefaultValue:    "false",
 		Deprecated:      false,
 		ToBeRemovedWith: "",
-		Description:     "Disables [EnableDelayedExpansion](https://ss64.com/nt/delayedexpansion.html) for error checking for when using [Window Batch](../shells/index.md#windows-batch) shell",
+		Description: "Disables [EnableDelayedExpansion](https://ss64.com/nt/delayedexpansion.html) for " +
+			"error checking for when using [Window Batch](../shells/index.md#windows-batch) shell",
 	},
 	{
 		Name:            NetworkPerBuild,
 		DefaultValue:    "false",
 		Deprecated:      false,
 		ToBeRemovedWith: "",
-		Description:     "Enables creation of a Docker [network per build](../executors/docker.md#networking) with the `docker` executor",
+		Description: "Enables creation of a Docker [network per build](../executors/docker.md#networking) with " +
+			"the `docker` executor",
 	},
 	{
 		Name:            UseLegacyKubernetesExecutionStrategy,
 		DefaultValue:    "true",
 		Deprecated:      false,
 		ToBeRemovedWith: "",
-		Description:     "When set to `false` disables execution of remote Kubernetes commands through `exec` in favor of `attach` to solve problems like [#4119](https://gitlab.com/gitlab-org/gitlab-runner/-/issues/4119)",
+		Description: "When set to `false` disables execution of remote Kubernetes commands through `exec` in " +
+			"favor of `attach` to solve problems like " +
+			"[#4119](https://gitlab.com/gitlab-org/gitlab-runner/-/issues/4119)",
 	},
 	{
 		Name:            UseDirectDownload,
 		DefaultValue:    "true",
 		Deprecated:      false,
 		ToBeRemovedWith: "",
-		Description:     "When set to `true` Runner tries to direct-download all artifacts instead of proxying through GitLab on a first try. Enabling might result in a download failures due to problem validating TLS certificate of Object Storage if it is enabled by GitLab",
+		Description: "When set to `true` Runner tries to direct-download all artifacts instead of proxying " +
+			"through GitLab on a first try. Enabling might result in a download failures due to problem validating " +
+			"TLS certificate of Object Storage if it is enabled by GitLab",
 	},
 	{
 		Name:            SkipNoOpBuildStages,
@@ -67,7 +73,8 @@ var flags = []FeatureFlag{
 		DefaultValue:    "false",
 		Deprecated:      true,
 		ToBeRemovedWith: "14.0",
-		Description:     "Use the old process termination that was used prior to GitLab 13.1 where only `SIGKILL` was sent",
+		Description: "Use the old process termination that was used prior to GitLab 13.1 where only `SIGKILL`" +
+			" was sent",
 	},
 }
 
